onSaved property
The callback to call when the user saves the options
scale is the scale of the wallpaper
color is the color to use if the wallpaper is scaled
Implementation
final Function(WallpaperScale, String) onSaved;
The callback to call when the user saves the options
scale is the scale of the wallpaper
color is the color to use if the wallpaper is scaled
final Function(WallpaperScale, String) onSaved;